/*---------------------------------------------------------------------------*/
/*                                                                           */
/*---------------------------------------------------------------------------*/
/*    Copyright (c) Becker & Hickl GmbH  2002-12  All Rights Reserved.       */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/* Title   : licence.H                                                       */
/* Purpose : Include file for programs using BH Licence  32-bit DLL under    */
/*              Windows.                                                     */
/*                                                                           */
/*---------------------------------------------------------------------------*/

/*- Defines -----------------------------------------------------------------*/



#ifdef __cplusplus
  extern "C"{
#endif

#define MAX_BH_PROTECTED_APP 14    // number of BH license-protected applic.

   // app_type defines in  ValidateRegLicense and  ValidateLicense functions 
#define SPCM_DLL_MSK           1
#define GVD_DLL_MSK            2
#define DCC_DLL_MSK            4
#define PCS_DLL_MSK            8       // used now for SPC-BURST-FCS (24.02.12)
#define PMS_DLL_MSK            16
#define PMS_LVD_MSK            32
#define MSA_DLL_MSK            64
#define GVD_LVD_MSK            128
#define DDG_DLL_MSK            256
#define SPCIMAGE_MSK           512
#define SPCM_DLL_LV_MSK        1024
#define DCC_LVD_MSK            2048
#define DDG_LVD_MSK            4096
#define MSA_LVD_MSK            8192
        
        // error codes definitions and bits flags for return value of
        //    ValidateRegLicense and  ValidateLicense functions
        
#define UNKNOWN_APP          -100   // unknown BH application type
#define SMALL_BUFFER         -101   // input buffer too small     
#define READ_LICENSE         -102   // cannot read license string from registry
#define WRONG_LICENSE        -103   // license not verified       
#define WRONG_APP_LICENSE    -104   // license not OK for the application
#define WRONG_LICENSE_DATE   -105   // wrong date coded in the license
#define LICENSE_DATE_EXPIRED -106   // license date expired
#define WRONG_ARGUMENT       -107   // function's argument not OK (e.g, NULL pointer)

// OLD_LIC_FLAG or NEW_LIC_FLAG must be present  when result is OK
#define OLD_LIC_FLAG          0x10000
#define NEW_LIC_FLAG          0x20000
#define TIM_EXP_FLAG          0x40000


#define DllExport   __declspec( dllexport )



/*--------------------------------------------------------------------------  
  GetInstallDir
  input par. :
      app_type  - application type
      InstallDir  - Install directory string 

  reads InstallDir string for the application app_type from registry
  looks at first in application specific path HKLM\SOFTWARE\BH\app_path 
    if not found reads common BH InstallDir from HKLM\SOFTWARE\BH
  if app_type = -1  reads common BH license from HKLM\SOFTWARE\BH
  
  if InstallDir string is not found in default key 
     ( 32/64b key when called from 32/64b application )
     the procedure tries to find it in alternate key 
       ( 32/64b key when called from 64/32b application )

  returns value < 0 - internal DLL error
  returns value > 0 when an error occured while accesing Windows registry
                     error code defined in winerror.h                                             
  returns 0 on success
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  GetInstallDir( int app_type, char *InstallDir );




/*--------------------------------------------------------------------------  
  Test_If_Installed
  input par. :
      int app_type  - application type
  finds installation path and looks for presence of one of the files (dll)
  when file exists returns > 0
       file not found return 0,
       error   < 0
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  Test_If_Installed( int app_type );




/*--------------------------------------------------------------------------  
  RegisterBHApp
  input par. :
      app_type - application type
      license   - license string 
  validates license string for the application
  if license is OK, writes license string to the application specific path
   in the registry  or,
      if app_type = -1, writes license string to HKLM\SOFTWARE\BH
  returns value < 0 when license is not OK (wrong CRC, not for app_type,
                                        license date expired)
  returns value > 0 when an error occured while accesing Windows registry
                     error code defined in winerror.h                                             
  returns value = 0 when license is OK and writing to the registry was successful
  --------------------------------------------------------------------------*/

DllExport int  __cdecl  RegisterBHApp( int app_type, char *license );




/*--------------------------------------------------------------------------  
  RegisterAllBHApp
  input par. :
      license   - license string 

  validates license string 
  if license is OK, 
    writes license string to HKLM\SOFTWARE\BH
    writes license string to the specific path in the registry 
          for each verified application
  returns value < 0 when license is not OK (wrong CRC, not for app_type,
                                        license date expired)
  returns value > 0 when an error occured while accesing Windows registry
                     error code defined in winerror.h                                             
  returns value = 0 when license is OK and writing to the registry was successful
  --------------------------------------------------------------------------*/

DllExport int  __cdecl  RegisterAllBHApp( char *license );





/*--------------------------------------------------------------------------  
  RegisterRegAllBHApp

  reads license string from HKLM\SOFTWARE\BH
  validates license string 
  if license is OK, 
    writes license string to HKLM\SOFTWARE\BH
    writes license string to the specific path in the registry 
          for each verified application
  returns value < 0 when license is not OK (wrong CRC, not for app_type,
                                        license date expired)
  returns value > 0 when an error occured while accesing Windows registry
                     error code defined in winerror.h                                             
  returns value = 0 when license is OK and writing to the registry was successful
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  RegisterRegAllBHApp( void );





/*--------------------------------------------------------------------------  
  ValidateLicense
  input par. :
      app_type  - application type
      license   - license string 

  returns value < 0 when license is not OK (wrong CRC, not for app_type,
                                        license date expired)
  returns value > 0, but less than 65536  -when an error occured while accesing
                        Windows registry - error code defined in winerror.h                                             
  returns value >= 65536 when license is OK : 
        - lower 16 bits = number of days left in case of date limited license
        - higher 16 bits flags 
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  ValidateLicense( int app_type,  char * license );




/*--------------------------------------------------------------------------  
  ValidateRegLicense
  reads license string for the application app_type from registry
       and verifies it
  if license string is not found in default key 
     ( 32/64b key when called from 32/64b application )
     the procedure tries to find it in alternate key 
       ( 32/64b key when called from 64/32b application )
  returns value < 0 when license is not OK (wrong CRC, not for app_type,
                                        license date expired)
  returns value > 0, but less than 65536  -when an error occured while accesing
                        Windows registry - error code defined in winerror.h                                             
  returns value >= 65536 when license is OK : 
        - lower 16 bits = number of days left in case of date limited license
        - higher 16 bits flags 
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  ValidateRegLicense( int app_type );



/*--------------------------------------------------------------------------  
  VerifyLicenseNumber
  input par. :
      license   - license string 

  when wrong CRC of license, returns 0
       otherwise returns  value from first 4 characters of license
       ( which says for which application license is verified (good) )
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  VerifyLicenseNumber ( char * license);




/*--------------------------------------------------------------------------  
  CheckLicenseString
  input par. :
      license   - license string 

  removes all control characters and spaces from the license string
      and overwrites the old string with the new one
  
  returns 0 on success
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  CheckLicenseString( char * license );





/*--------------------------------------------------------------------------  
  CheckOldLicenseString
  input par. :
      license   - license string 

  if license has the length of the old license style add two spaces 
      in order_no field
  returns 0 on success
  --------------------------------------------------------------------------*/
DllExport int  __cdecl CheckOldLicenseString( char * license );






/*--------------------------------------------------------------------------  
  GetLicenseString
  input par. :
      app_type  - application type
      license   - license string 

  reads license string for the application app_type from registry
  looks at first in application specific path HKLM\SOFTWARE\BH\app_path 
    if not found reads common BH license from HKLM\SOFTWARE\BH
  if app_type = -1  reads common BH license from HKLM\SOFTWARE\BH
  
  if license is not found in default key 
     ( 32/64b key when called from 32/64b application )
     the procedure tries to find it in alternate key 
       ( 32/64b key when called from 64/32b application )
  returns value < 0 - internal DLL error
  returns value > 0 when an error occured while accesing Windows registry
                     error code defined in winerror.h                                             
  returns 0 on success
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  GetLicenseString( int app_type,  char * license );



/*--------------------------------------------------------------------------
  RegRemoveLicenseNumber
  removes "LicenseNumber" value from the registry
    if path = NULL   from HKLM\\SOFTWARE\\BH
    otherwise        from HKLM\\SOFTWARE\\BH\\path

  removes "LicenseNumber" value also from the alternate registry key
       ( 32/64b key when called from 64/32b application )
  returns 0 on success
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  RegRemoveLicenseNumber( char * path );



/*--------------------------------------------------------------------------  
  GetLicenseDate
  input par. :
      license   - license string 
      day   -   pointer to day variable
      month -   pointer to month variable
      year  -   pointer to year variable
      limited - pointer to limited variable

  analyze license string. 
  If license CRC is OK and license contains date ( newest license style),
  sets day, month, year and limited variables.
  'limited' is set to 1 if license is time limited, 0 otherwise.
  
  returns 0 on success
  returns value < 0 - on DLL error
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  GetLicenseDate( char * license, int *day, int *month,
                                        int *year, int *limited);




/*--------------------------------------------------------------------------  
  File_Exists
  input par. :
      filename   - string 

  when file exists - returns 1
       file not found  - return 0,
       error   < 0
  --------------------------------------------------------------------------*/
DllExport int  __cdecl  File_Exists (  char * filename);




/*- The End -----------------------------------------------------------------*/

#ifdef __cplusplus
  }
#endif
